@@ -9,7 +9,7 @@ __author__ = "Rene Buffat"
 __copyright__ = "Copyright 2014"
 __credits__ = []
 __license__ = "Apache 2.0"
-__version__ = "0.1.2"
+__version__ = "0.1.3"
 __maintainer__ = "Rene Buffat"
 __email__ = "buffat@gmail.com"
 __status__ = "Development"
@@ -17,7 +17,11 @@ __status__ = "Development"
 
 class ValidationLevel(object):
 
-    """Validation levels."""
+    """ Validation levels:
+        - no: no validation
+        - warn: issue warnings
+        - transition: try to transition values to follow specification
+        - error: raise exceptions when values are not according specification"""
     no = "no"
     warn = "warm"
     transition = "transition"
