@@ -7,13 +7,19 @@ import six
 import pyidf
 from pyidf import ValidationLevel
 
+
 logger = logging.getLogger("pyidf")
 logger.addHandler(logging.NullHandler())
 
 
 class DataObject(object):
 
-    schema = {}
+    _schema = {}
+
+    @property
+    def schema(self):
+        """Get schema of class."""
+        return self._schema
 
     def __init__(self):
         """Init data dictionary object."""
@@ -643,6 +649,14 @@ class DataObject(object):
                 out.append((field_txt, self._to_str(vals[i])))
         return out
 
+    def field(self, name):
+        name_lower = name.lower()
+        if name_lower in self.schema['fields']:
+            return self.schema['fields'][name_lower]
+        elif name_lower in self.schema['extensible-fields']:
+            return self.schema['extensible-fields'][name_lower]
+        return
+
     def extensible_field_index(self, name):
         return list(
             self.schema['extensible-fields'].keys()).index(name.lower())
