@@ -20,31 +20,39 @@ class ParametricSetValueForRun(DataObject):
         of a parameters and sets the parameter to different values depending on which
         run is being simulated.
     """
-    schema = {'extensible-fields': OrderedDict([(u'value for run 1',
-                                                 {'name': u'Value for Run 1',
-                                                  'pyname': u'value_for_run_1',
-                                                  'required-field': False,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'alpha'})]),
-              'fields': OrderedDict([(u'name',
-                                      {'name': u'Name',
-                                       'pyname': u'name',
-                                       'required-field': True,
-                                       'autosizable': False,
-                                       'autocalculatable': False,
-                                       'type': u'alpha'})]),
-              'format': None,
-              'group': u'Parametrics',
-              'min-fields': 2,
-              'name': u'Parametric:SetValueForRun',
-              'pyname': u'ParametricSetValueForRun',
-              'required-object': False,
-              'unique-object': False}
+    _schema = {'extensible-fields': OrderedDict([(u'value for run 1',
+                                                  {'name': u'Value for Run 1',
+                                                   'pyname': u'value_for_run_1',
+                                                   'required-field': False,
+                                                   'autosizable': False,
+                                                   'autocalculatable': False,
+                                                   'type': u'alpha'})]),
+               'fields': OrderedDict([(u'name',
+                                       {'name': u'Name',
+                                        'pyname': u'name',
+                                        'required-field': True,
+                                        'autosizable': False,
+                                        'autocalculatable': False,
+                                        'type': u'alpha'})]),
+               'format': None,
+               'group': u'Parametrics',
+               'min-fields': 2,
+               'name': u'Parametric:SetValueForRun',
+               'pyname': u'ParametricSetValueForRun',
+               'required-object': False,
+               'unique-object': False}
 
     @property
     def name(self):
-        """Get name.
+        """field `Name` Parameter Name Must begin with the dollar sign
+        character. The second character must be a letter. Remaining characters
+        may only be letters or numbers. No spaces allowed.
+
+        Args:
+            value (str): value for IDD Field `Name`
+
+        Raises:
+            ValueError: if `value` is not a valid value
 
         Returns:
             str: the value of `name` or None if not set
@@ -54,19 +62,7 @@ class ParametricSetValueForRun(DataObject):
 
     @name.setter
     def name(self, value=None):
-        """Corresponds to IDD field `Name` Parameter Name Must begin with the
-        dollar sign character. The second character must be a letter. Remaining
-        characters may only be letters or numbers. No spaces allowed.
-
-        Args:
-            value (str): value for IDD Field `Name`
-                if `value` is None it will not be checked against the
-                specification and is assumed to be a missing value
-
-        Raises:
-            ValueError: if `value` is not a valid value
-
-        """
+        """Corresponds to IDD field `Name`"""
         self["Name"] = value
 
     def add_extensible(self,
@@ -114,31 +110,37 @@ class ParametricLogic(DataObject):
         parametric runs and not others. A single Parametric:Logic object is allowed per file.
         Consult the Input Output Reference for available commands and syntax.
     """
-    schema = {'extensible-fields': OrderedDict([(u'parametric logic line 1',
-                                                 {'name': u'Parametric Logic Line 1',
-                                                  'pyname': u'parametric_logic_line_1',
-                                                  'required-field': False,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'alpha'})]),
-              'fields': OrderedDict([(u'name',
-                                      {'name': u'Name',
-                                       'pyname': u'name',
-                                       'required-field': True,
-                                       'autosizable': False,
-                                       'autocalculatable': False,
-                                       'type': u'alpha'})]),
-              'format': None,
-              'group': u'Parametrics',
-              'min-fields': 2,
-              'name': u'Parametric:Logic',
-              'pyname': u'ParametricLogic',
-              'required-object': False,
-              'unique-object': True}
+    _schema = {'extensible-fields': OrderedDict([(u'parametric logic line 1',
+                                                  {'name': u'Parametric Logic Line 1',
+                                                   'pyname': u'parametric_logic_line_1',
+                                                   'required-field': False,
+                                                   'autosizable': False,
+                                                   'autocalculatable': False,
+                                                   'type': u'alpha'})]),
+               'fields': OrderedDict([(u'name',
+                                       {'name': u'Name',
+                                        'pyname': u'name',
+                                        'required-field': True,
+                                        'autosizable': False,
+                                        'autocalculatable': False,
+                                        'type': u'alpha'})]),
+               'format': None,
+               'group': u'Parametrics',
+               'min-fields': 2,
+               'name': u'Parametric:Logic',
+               'pyname': u'ParametricLogic',
+               'required-object': False,
+               'unique-object': True}
 
     @property
     def name(self):
-        """Get name.
+        """field `Name`
+
+        Args:
+            value (str): value for IDD Field `Name`
+
+        Raises:
+            ValueError: if `value` is not a valid value
 
         Returns:
             str: the value of `name` or None if not set
@@ -148,17 +150,7 @@ class ParametricLogic(DataObject):
 
     @name.setter
     def name(self, value=None):
-        """Corresponds to IDD field `Name`
-
-        Args:
-            value (str): value for IDD Field `Name`
-                if `value` is None it will not be checked against the
-                specification and is assumed to be a missing value
-
-        Raises:
-            ValueError: if `value` is not a valid value
-
-        """
+        """Corresponds to IDD field `Name`"""
         self["Name"] = value
 
     def add_extensible(self,
@@ -206,34 +198,40 @@ class ParametricRunControl(DataObject):
         Controls which parametric runs are simulated. This object is optional. If it is not
         included, then all parametric runs are performed.
     """
-    schema = {'extensible-fields': OrderedDict([(u'perform run 1',
-                                                 {'name': u'Perform Run 1',
-                                                  'pyname': u'perform_run_1',
-                                                  'default': u'Yes',
-                                                  'required-field': False,
-                                                  'autosizable': False,
-                                                  'accepted-values': [u'Yes',
-                                                                      u'No'],
-                                                     'autocalculatable': False,
-                                                     'type': 'alpha'})]),
-              'fields': OrderedDict([(u'name',
-                                      {'name': u'Name',
-                                       'pyname': u'name',
-                                       'required-field': False,
-                                       'autosizable': False,
-                                       'autocalculatable': False,
-                                       'type': u'alpha'})]),
-              'format': None,
-              'group': u'Parametrics',
-              'min-fields': 2,
-              'name': u'Parametric:RunControl',
-              'pyname': u'ParametricRunControl',
-              'required-object': False,
-              'unique-object': True}
+    _schema = {'extensible-fields': OrderedDict([(u'perform run 1',
+                                                  {'name': u'Perform Run 1',
+                                                   'pyname': u'perform_run_1',
+                                                   'default': u'Yes',
+                                                   'required-field': False,
+                                                   'autosizable': False,
+                                                   'accepted-values': [u'Yes',
+                                                                       u'No'],
+                                                      'autocalculatable': False,
+                                                      'type': 'alpha'})]),
+               'fields': OrderedDict([(u'name',
+                                       {'name': u'Name',
+                                        'pyname': u'name',
+                                        'required-field': False,
+                                        'autosizable': False,
+                                        'autocalculatable': False,
+                                        'type': u'alpha'})]),
+               'format': None,
+               'group': u'Parametrics',
+               'min-fields': 2,
+               'name': u'Parametric:RunControl',
+               'pyname': u'ParametricRunControl',
+               'required-object': False,
+               'unique-object': True}
 
     @property
     def name(self):
-        """Get name.
+        """field `Name`
+
+        Args:
+            value (str): value for IDD Field `Name`
+
+        Raises:
+            ValueError: if `value` is not a valid value
 
         Returns:
             str: the value of `name` or None if not set
@@ -243,17 +241,7 @@ class ParametricRunControl(DataObject):
 
     @name.setter
     def name(self, value=None):
-        """Corresponds to IDD field `Name`
-
-        Args:
-            value (str): value for IDD Field `Name`
-                if `value` is None it will not be checked against the
-                specification and is assumed to be a missing value
-
-        Raises:
-            ValueError: if `value` is not a valid value
-
-        """
+        """Corresponds to IDD field `Name`"""
         self["Name"] = value
 
     def add_extensible(self,
@@ -300,31 +288,37 @@ class ParametricFileNameSuffix(DataObject):
         Defines the suffixes to be appended to the idf and output file names for each
         parametric run. If this object is omitted, the suffix will default to the run number.
     """
-    schema = {'extensible-fields': OrderedDict([(u'suffix for file name in run 1',
-                                                 {'name': u'Suffix for File Name in Run 1',
-                                                  'pyname': u'suffix_for_file_name_in_run_1',
-                                                  'required-field': False,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'alpha'})]),
-              'fields': OrderedDict([(u'name',
-                                      {'name': u'Name',
-                                       'pyname': u'name',
-                                       'required-field': False,
-                                       'autosizable': False,
-                                       'autocalculatable': False,
-                                       'type': u'alpha'})]),
-              'format': None,
-              'group': u'Parametrics',
-              'min-fields': 2,
-              'name': u'Parametric:FileNameSuffix',
-              'pyname': u'ParametricFileNameSuffix',
-              'required-object': False,
-              'unique-object': True}
+    _schema = {'extensible-fields': OrderedDict([(u'suffix for file name in run 1',
+                                                  {'name': u'Suffix for File Name in Run 1',
+                                                   'pyname': u'suffix_for_file_name_in_run_1',
+                                                   'required-field': False,
+                                                   'autosizable': False,
+                                                   'autocalculatable': False,
+                                                   'type': u'alpha'})]),
+               'fields': OrderedDict([(u'name',
+                                       {'name': u'Name',
+                                        'pyname': u'name',
+                                        'required-field': False,
+                                        'autosizable': False,
+                                        'autocalculatable': False,
+                                        'type': u'alpha'})]),
+               'format': None,
+               'group': u'Parametrics',
+               'min-fields': 2,
+               'name': u'Parametric:FileNameSuffix',
+               'pyname': u'ParametricFileNameSuffix',
+               'required-object': False,
+               'unique-object': True}
 
     @property
     def name(self):
-        """Get name.
+        """field `Name`
+
+        Args:
+            value (str): value for IDD Field `Name`
+
+        Raises:
+            ValueError: if `value` is not a valid value
 
         Returns:
             str: the value of `name` or None if not set
@@ -334,17 +328,7 @@ class ParametricFileNameSuffix(DataObject):
 
     @name.setter
     def name(self, value=None):
-        """Corresponds to IDD field `Name`
-
-        Args:
-            value (str): value for IDD Field `Name`
-                if `value` is None it will not be checked against the
-                specification and is assumed to be a missing value
-
-        Raises:
-            ValueError: if `value` is not a valid value
-
-        """
+        """Corresponds to IDD field `Name`"""
         self["Name"] = value
 
     def add_extensible(self,
